# bonbon

> A python utility library to help with data processing.

# pypi

> Apply changes to repo.

> Increment setup.py version number.

> `python setup.py sdist bdist_wheel`

> `twine upload dist/*`
